Note: this is not emmeans::contrast. contrast() is mixeff's fixed-effect
contrast front door. R validates the contrast matrix shape, then asks Rust
to evaluate estimability, method prerequisites, standard errors, degrees of
freedom, statistics, p-values, reliability, and unavailable reasons.
Usage
# S3 method for class 'mm_glmm'
contrast(fit, L, rhs = 0, method = c("asymptotic", "wald"), ...)
contrast(
fit,
L,
rhs = 0,
method = c("auto", "satterthwaite", "kenward_roger", "bootstrap", "asymptotic",
"boundary_lrt", "none"),
bootstrap = NULL,
...
)
# S3 method for class 'mm_lmm'
contrast(
fit,
L,
rhs = 0,
method = c("auto", "satterthwaite", "kenward_roger", "bootstrap", "asymptotic",
"boundary_lrt", "none"),
bootstrap = NULL,
...
)Arguments
- fit
A fitted
mm_lmm.- L
A numeric contrast vector or matrix with one column per fixed effect.
- rhs
Numeric right-hand side, recycled to the number of contrasts.
- method
Requested inference method.
- ...
Reserved for future methods.
- bootstrap
Optional
bootstrap_control()object formethod = "bootstrap".