Draws Gaussian responses from the stored fixed effects, random-effect covariance summaries, and residual scale.
Usage
# S3 method for class 'mm_lmm'
simulate(object, nsim = 1, seed = NULL, re.form = NULL, ...)Draws Gaussian responses from the stored fixed effects, random-effect covariance summaries, and residual scale.
# S3 method for class 'mm_lmm'
simulate(object, nsim = 1, seed = NULL, re.form = NULL, ...)